@@ -120,7 +120,7 @@ def _synchronize_node(configfile, node):
         extra_opts += " --copy-links"
     ssh_opts = ""
     if env.ssh_config_path:
-        ssh_opts += " -F %s" % os.path.expanduser(env.ssh_config_path)
+        ssh_opts += " -F %s" % os.path.expanduser(env.ssh_config_pat.h)
     if env.encrypted_data_bag_secret:
         put(env.encrypted_data_bag_secret,
             "/etc/chef/encrypted_data_bag_secret",
@@ -135,6 +135,22 @@ def _synchronize_node(configfile, node):
         extra_opts=extra_opts,
         ssh_opts=ssh_opts
     )
+
+    if env.sync_packages_dest_dir and env.sync_packages_local_dir:
+      print("Uploading packages from {0} to remote server {2} directory "
+        "{1}").format(env.sync_packages_local_dir, env.sync_packages_dest_dir, env.host_string)
+      try:
+        rsync_project(
+          env.sync_packages_dest_dir,
+          env.sync_packages_local_dir+"/*",
+          exclude=('*.svn', '.bzr*', '.git*', '.hg*'),
+          delete=True,
+          extra_opts=extra_opts,
+          ssh_opts=ssh_opts
+        )
+      except:
+        print("Warning: package upload failed. Continuing cooking...")
+
     _add_environment_lib()  # NOTE: Chef 10 only
 
 
@@ -296,7 +312,7 @@ def build_node_data_bag():
 
         # Save node data bag item
         with open(os.path.join(
-                    'data_bags', 'node', node['id'] + '.json'), 'w') as f:
+                  'data_bags', 'node', node['id'] + '.json'), 'w') as f:
             f.write(json.dumps(node))
 
 
@@ -342,10 +358,10 @@ def _add_environment_lib():
 
 def _configure_node():
     """Exectutes chef-solo to apply roles and recipes to a node"""
+    print("")
     msg = "Cooking..."
     if env.parallel:
         msg = "[{0}]: {1}".format(env.host_string, msg)
-    print("")
     print(msg)
     # Backup last report
     with settings(hide('stdout', 'warnings', 'running'), warn_only=True):
@@ -364,7 +380,7 @@ def _configure_node():
         output = sudo(cmd)
     if (output.failed or "FATAL: Stacktrace dumped" in output or
             ("Chef Run complete" not in output and
-            "Report handlers complete" not in output)):
+             "Report handlers complete" not in output)):
         if 'chef-solo: command not found' in output:
             print(
                 colors.red(
