@@ -63,7 +63,12 @@ def configure(current_node=None):
     current_node = current_node or {}
     # Ensure that the /tmp/chef-solo/cache directory exist
     cache_dir = "{0}/cache".format(env.node_work_path)
-    if not exists(cache_dir):
+    # First remote call, could go wrong
+    try:
+        cache_exists = exists(cache_dir)
+    except EOFError as e:
+        abort("Could not login to node, got: {0}".format(e))
+    if not cache_exists:
         with settings(hide('running', 'stdout'), warn_only=True):
             output = sudo('mkdir -p {0}'.format(cache_dir))
         if output.failed:
@@ -103,9 +108,9 @@ def configure(current_node=None):
                             context=data, use_sudo=True, backup=False,
                             mode=0400)
         except SystemExit:
-            error = ("Failed to upload '/etc/chef/solo.rb'\n"
-            "This can happen when the deployment user does not have a "
-            "home directory, which is needed as a temporary location")
+            error = ("Failed to upload '/etc/chef/solo.rb'\nThis "
+                     "can happen when the deployment user does not have a "
+                     "home directory, which is needed as a temporary location")
             abort(error)
     with hide('stdout'):
         sudo('chown root:$(id -g -n root) {0}'.format('/etc/chef/solo.rb'))
